==> nextcloud-25.0.12.tgz: nextcloud/apps/serverinfo/l10n/tr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "İşlemci bilgileri alınamadı",
    "Load average: {cpu} (last minute)" : "Ortalama yük: {cpu} (son bir dakika)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Toplam: {memTotalBytes}/Güncel kullanım: {memUsageBytes}",
    "RAM info not available" : "RAM bilgileri alınamadı",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Toplam: {swapTotalBytes}/Güncel kullanım: {swapUsageBytes}",
    "SWAP info not available" : "SWAP bilgileri alınamadı",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "System" : "Sistem",
    "Monitoring" : "İzleniyor",
    "Monitoring app with useful server information" : "Yararlı sunucu bilgileri sunan izleme uygulaması",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "İşlemci yükü, bellek ve disk kullanımı, kullanıcı sayısı gibi sunucu hakkında çeşitli bilgiler sağlar. ",
    "Operating System:" : "İşletim sistemi:",
    "CPU:" : "İşlemci",
    "Unknown Processor" : "İşlemci bilinmiyor",
    "Memory:" : "Bellek:",
    "Server time:" : "Sunucu zamanı:",
    "Uptime:" : "Çalışma süresi:",
    "Temperature" : "Sıcaklık",
    "Load" : "Yük",
    "Memory" : "Bellek",
    "Disk" : "Disk",
    "Mount:" : "Takılı:",
    "Filesystem:" : "Dosya sistemi:",
    "Size:" : "Boyut:",
    "Available:" : "Kullanılabilir:",
    "Used:" : "Kullanılan:",
    "Files:" : "Dosyalar:",
    "Storages:" : "Depolama birimleri:",
    "Free Space:" : "Boş alan:",
    "Network" : "Ağ",
    "Hostname:" : "Sunucu adı:",
    "DNS:" : "DNS:",
    "Gateway:" : "Ağ geçidi:",
    "Status:" : "Durum:",
    "Speed:" : "Hız:",
    "Duplex:" : "Çift taraflı:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Etkin kullanıcılar",
    "Total users:" : "Kullanıcı sayısı:",
    "24 hours:" : "24 saat:",
    "1 hour:" : "1 saat:",
    "5 mins:" : "5 dakika:",
    "Shares" : "Paylaşımlar",
    "Users:" : "Kullanıcılar:",
    "Groups:" : "Gruplar:",
    "Links:" : "Bağlantılar:",
    "Emails:" : "E-postalar:",
    "Federated sent:" : "Birleşik gönderilen:",
    "Federated received:" : "Birleşik alınan:",
    "Talk conversations:" : "Talk görüşmeleri:",
    "PHP" : "PHP",
    "Version:" : "Sürüm:",
    "Memory limit:" : "Bellek sınırı:",
    "Max execution time:" : "En uzun çalışma süresi:",
    "Upload max size:" : "En büyük yükleme boyutu:",
    "OPcache Revalidate Frequency:" : "OPcache yeniden doğrulama sıklığı:",
    "Extensions:" : "Eklentiler:",
    "Unable to list extensions" : "Eklentiler listelenemedi",
    "Show phpinfo" : "PHP bilgilerini görüntüle",
    "Database" : "Veri tabanı",
    "Type:" : "Tür:",
    "External monitoring tool" : "Dış izleme aracı",
    "You can connect an external monitoring tool by using this end point:" : "Bu uç noktasını kullanarak bir dış izleme aracı bağlayabilirsiniz:",
    "Copy" : "Kopyala",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Adresin sonuna \"?format=json\" eklendiğinde sonuçlar JSON biçiminde alınabilir.",
    "To use an access token, please generate one then set it using the following command:" : "Erişim kodunu kullanmak için yeni bir kod üretip şu komutu yürüterek ayarlayın:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ardından yukarıdaki adresi sorgularken kodu \"NC-Token\" üst bilgisi ile gönderin.",
    "You will get a notification once one of your disks is nearly full." : "Diskinizde boş alan azaldığında bir bildirim alacaksınız."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-26.0.10.tgz: nextcloud/apps/serverinfo/l10n/tr.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "İşlemci bilgileri alınamadı",
    "Load average: {cpu} (last minute)" : "Ortalama yük: {cpu} (son bir dakika)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Toplam: {memTotalBytes}/Güncel kullanım: {memUsageBytes}",
    "RAM info not available" : "RAM bilgileri alınamadı",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Toplam: {swapTotalBytes}/Güncel kullanım: {swapUsageBytes}",
    "SWAP info not available" : "SWAP bilgileri alınamadı",
    "Copied!" : "Kopyalandı!",
    "Not supported!" : "Desteklenmiyor!",
    "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
    "Press Ctrl-C to copy." : "Kopyalamak için Ctrl-C tuşlarına basın.",
    "System" : "Sistem",
    "Monitoring" : "İzleniyor",
    "Monitoring app with useful server information" : "Yararlı sunucu bilgileri sunan izleme uygulaması",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "İşlemci yükü, bellek ve disk kullanımı, kullanıcı sayısı gibi sunucu hakkında çeşitli bilgiler sağlar. ",
    "Operating System:" : "İşletim sistemi:",
    "CPU:" : "İşlemci",
    "Unknown Processor" : "İşlemci bilinmiyor",
    "Memory:" : "Bellek:",
    "Server time:" : "Sunucu zamanı:",
    "Uptime:" : "Çalışma süresi:",
    "Temperature" : "Sıcaklık",
    "Load" : "Yük",
    "Memory" : "Bellek",
    "Disk" : "Disk",
    "Mount:" : "Takılı:",
    "Filesystem:" : "Dosya sistemi:",
    "Size:" : "Boyut:",
    "Available:" : "Kullanılabilir:",
    "Used:" : "Kullanılan:",
    "Files:" : "Dosyalar:",
    "Storages:" : "Depolama birimleri:",
    "Free Space:" : "Boş alan:",
    "Network" : "Ağ",
    "Hostname:" : "Sunucu adı:",
    "DNS:" : "DNS:",
    "Gateway:" : "Ağ geçidi:",
    "Status:" : "Durum:",
    "Speed:" : "Hız:",
    "Duplex:" : "Çift taraflı:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Etkin kullanıcılar",
    "Total users:" : "Kullanıcı sayısı:",
    "24 hours:" : "24 saat:",
    "1 hour:" : "1 saat:",
    "5 mins:" : "5 dakika:",
    "Shares" : "Paylaşımlar",
    "Users:" : "Kullanıcılar:",
    "Groups:" : "Gruplar:",
    "Links:" : "Bağlantılar:",
    "Emails:" : "E-postalar:",
    "Federated sent:" : "Birleşik gönderilen:",
    "Federated received:" : "Birleşik alınan:",
    "Talk conversations:" : "Talk görüşmeleri:",
    "PHP" : "PHP",
    "Version:" : "Sürüm:",
    "Memory limit:" : "Bellek sınırı:",
    "Max execution time:" : "En uzun çalışma süresi:",
    "Upload max size:" : "En büyük yükleme boyutu:",
    "OPcache Revalidate Frequency:" : "OPcache yeniden doğrulama sıklığı:",
    "Extensions:" : "Eklentiler:",
    "Unable to list extensions" : "Eklentiler listelenemedi",
    "Show phpinfo" : "PHP bilgilerini görüntüle",
    "Database" : "Veri tabanı",
    "Type:" : "Tür:",
    "External monitoring tool" : "Dış izleme aracı",
    "Use this end point to connect an external monitoring tool:" : "Bir dış izleme aracına bağlanmak için bu uç noktayı kullanın:",
    "Copy" : "Kopyala",
    "Output in JSON" : "JSON çıktısı",
    "Skip app updates (including app updates will send an external request to the app store)" : "Uygulama güncellemelerini atla (uygulama güncellemeleri ile birlikte uygulama mağazasına bir dış istek gönderilir)",
    "Skip server update" : "Sunucu güncellemesini atla",
    "To use an access token, please generate one then set it using the following command:" : "Erişim kodunu kullanmak için yeni bir kod üretip şu komutu yürüterek ayarlayın:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Ardından yukarıdaki adresi sorgularken kodu \"NC-Token\" üst bilgisi ile gönderin."
},
"nplurals=2; plural=(n > 1);");
